@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -53,7 +53,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.8 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.9 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -78,23 +78,21 @@ class SyL_ErrorWeb extends SyL_Error
         $error_trace = SYL_ERROR_TRACE ? $this->getTraceHtml() : '';
 
         // 顼ɽȽ
-        $error_View_type = explode('-', SYL_ERROR_FORWARD_TYPE);
-        switch (strtolower($error_View_type[0])) {
-        case 'template': $error_View_type[0] = 'Template'; break;
-        case 'redirect': $error_View_type[0] = 'Redirect'; break;
-        default:         $error_View_type[0] = 'Default';  break;
-        }
-
-        if (!isset($error_View_type[1])) {
-            $error_View_type[1] = '';
+        $error_View_type = '';
+        $view_type = explode(':', SYL_ERROR_FORWARD_TYPE);
+        switch (strtolower($view_type[0])) {
+        case 'view':
+        case 'layout':   $error_View_type = 'Template'; break;
+        case 'redirect': $error_View_type = 'Redirect'; break;
+        default:         $error_View_type = 'Default';  break;
         }
 
         // 顼ɽ
-        $func_name = "displayError{$error_View_type[0]}";
+        $func_name = "displayError{$error_View_type}";
         // 顼å
         $error_string = SYL_ERROR ? "[{$error_type}] {$error_message}" : SYL_ERROR_MESSAGE;
         // 顼åɽ
-        $this->{$func_name}($error_string, $error_trace, $error_View_type[1]);
+        $this->{$func_name}($error_string, $error_trace, $view_type);
         // 
         $this->logging();
     }
@@ -129,14 +127,53 @@ class SyL_ErrorWeb extends SyL_Error
         // ǡ饹
         include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
         $dm =& new SyL_DataManager($this->controller);
-        $dm->setTemplateType($view_type);
+        $dm->setViewParameter('viewtype', $view_type[1]);
+        if ($view_type[0] == 'layout') {
+            $dm->setViewParameter('viewlayout', 'true');
+        } else {
+            $dm->setViewParameter('viewlayout', 'false');
+            if ($view_type[1] == 'customize') {
+                $dm->setViewParameter('customizedviewclass', $view_type[2]);
+                $dm->setViewParameter('customizedviewfile',  $view_type[3]);
+            }
+        }
         $dm->setTemplateFile(SYL_ERROR_FORWARD_FILE);
+        $dm->setParameter('error_message', $error_string);
+        $dm->setParameter('error_trace',   $error_trace);
 
         // ӥ塼饹
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_View.php';
-        $view =& SyL_View::getObject($dm);
-        $view->setParameter('error_message', $error_string);
-        $view->setParameter('error_trace',   $error_trace);
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Layout.php';
+        $view =& SyL_Layout::getObject($dm);
+        $view->render();
+
+        // ̱饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Response.php';
+        $res =& SyL_Response::getInstance();
+        $res->display($view);
+    }
+
+    /**
+     * 쥤ȥ顼
+     *
+     * @access private
+     * @param string 顼å
+     * @param string 顼ȥ졼
+     * @param string ӥ塼
+     */
+    function displayErrorView($error_string, $error_trace, $view_type)
+    {
+        // ǡ饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_DataManager.php';
+        $dm =& new SyL_DataManager($this->controller);
+        $dm->setViewParameter('defaultView', $view_type);
+        $dm->setViewParameter('defaultView', $view_type);
+        $dm->setTemplateFile(SYL_ERROR_FORWARD_FILE);
+        $dm->setParameter('error_message', $error_string);
+        $dm->setParameter('error_trace',   $error_trace);
+
+        // ӥ塼饹
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Layout.php';
+        $view =& SyL_Layout::getObject($dm);
         $view->render();
 
         // ̱饹
