@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.6 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -62,7 +62,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.6 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo2.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo2 extends SyL_Router
@@ -135,7 +135,7 @@ class SyL_RouterPathinfo2 extends SyL_Router
         }
 
         // ֤
-        if ($action != null) {
+        if ($action !== null) {
             $this->action_name = $action;
         }
 
