@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.2 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.3 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,18 +44,11 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_ComponentMethod.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataManager.php,v 1.2 2006/12/25 17:30:18 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataManager.php,v 1.3 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataManager
 {
-    /**
-     * ƥץ졼ȥ
-     * 
-     * @access private
-     * @var string
-     */
-    var $template_type = '';
     /**
      * ƥץ졼ȥե
      * 
@@ -64,26 +57,19 @@ class SyL_DataManager
      */
     var $template_file = '';
     /**
-     * ޥӥ塼ե
+     * ӥ塼ѥ᡼
+     * 
+     * @access private
+     * @var array
+     */
+    var $view_parameters = array();
+    /**
+     * ѥ᡼
      * 
      * @access private
      * @var string
      */
-    var $customized_view_file = '';
-    /**
-     * ޥӥ塼饹̾
-     * 
-     * @access private
-     * @var string
-     */
-    var $customized_view_class = '';
-    /**
-     * 󥪥֥
-     * 
-     * @access private
-     * @var object
-     */
-    var $action = null;
+    var $parameters = array();
     /**
      * ȥ饪֥
      * 
@@ -186,28 +172,6 @@ class SyL_DataManager
         return is_object($this->router) ? $this->router->getPathInfoArray() : null;
     }
 
-    /**
-     * ƥץ졼ȥפ򥻥åȥ
-     * 
-     * @access public
-     * @param string ƥץ졼
-     */
-    function setTemplateType($template_type)
-    {
-        $this->template_type = $template_type;
-    }
-
-    /**
-     * ƥץ졼ȥפ
-     * 
-     * @access public
-     * @return string ƥץ졼ȥ
-     */
-    function getTemplateType()
-    {
-        return $this->template_type;
-    }
-
     /**
      * ƥץ졼ȥե򥻥å
      * 
@@ -247,45 +211,34 @@ class SyL_DataManager
         SyL_Loggers::debug("[DataManager] template info  dir: {$template_dir} file: {$template_file}");
 
         // ե¸ߥå
-        if (!$real_path || !preg_match($reg, $real_path)) {
+        if (!preg_match($reg, $real_path)) {
             SyL_Response::redirect404();
         }
         return $template_file;
     }
 
     /**
-     * ޥӥ塼å
+     * ӥ塼ѥ᡼å
      * 
      * @access public
-     * @param string ޥӥ塼ե
-     * @param string ޥӥ塼饹
+     * @param string ӥ塼ѥ᡼̾
+     * @param string ӥ塼ѥ᡼
      */
-    function setCustomizedView($customized_view_file, $customized_view_class)
+    function setViewParameter($name, $value)
     {
-        $this->customized_view_file  = $customized_view_file;
-        $this->customized_view_class = $customized_view_class;
+        $this->view_parameters[$name] = $value;
     }
 
     /**
-     * ޥӥ塼ե
+     * ӥ塼ѥ᡼
      * 
      * @access public
-     * @return string ޥӥ塼ե
+     * @param string ӥ塼ѥ᡼̾
+     * @return string ӥ塼ѥ᡼
      */
-    function getCustomizedViewFile()
+    function getViewParameter($name)
     {
-        return $this->convertPath($this->customized_view_file, false);
-    }
-
-    /**
-     * ޥӥ塼饹
-     * 
-     * @access public
-     * @return string ޥӥ塼饹
-     */
-    function getCustomizedViewClass()
-    {
-        return $this->customized_view_class;
+        return isset($this->view_parameters[$name]) ? $this->view_parameters[$name] : '';
     }
 
     /**
@@ -298,7 +251,7 @@ class SyL_DataManager
     function convertPath($path, $is_dir_path=false)
     {
         if ($is_dir_path && !preg_match('/(\\\\|\/)$/', $path)) {
-            $path = $path . '/';
+            $path .= '/';
         } else if (!$is_dir_path && preg_match('/^(\\\\|\/)/', $path)) {
             $path = substr($path, 1);
         }
@@ -352,30 +305,84 @@ class SyL_DataManager
         return $this->controller->container->getComponent($name);
     }
 
+
+    /**
+     * 쥤ȥѥ᡼򥻥å
+     * 
+     * @access public
+     * @param string ѥ᡼̾
+     * @param mixed ѥ᡼
+     */
+    function setParameter($name, $value)
+    {
+        $this->parameters[$name] = $value;
+    }
+
+    /**
+     * 쥤ȥѥ᡼򥻥åȡʻȡ
+     *
+     * @access public
+     * @param string ѥ᡼̾
+     * @param mixed ѥ᡼
+     */
+    function setParameterRef($name, &$value)
+    {
+        $this->parameters[$name] =& $value;
+    }
+
+    /**
+     * ѥ᡼
+     * 
+     * @access public
+     * @return array ѥ᡼
+     */
+    function &getParameters()
+    {
+        return $this->parameters;
+    }
+
     /**
      * 󥪥֥Ȥ򥻥å
      * 
      * @access public
      */
-    function setAction()
+    function setActionValues()
     {
         if ($this->controller->container->isComponent(SYL_ACTION_KEY)) {
-            $this->action =& $this->getComponent(SYL_ACTION_KEY);
+            $action =& $this->getComponent(SYL_ACTION_KEY);
+
+            // 󥪥֥Ȥ¸ߤʥ¹ԸˤʤС
+            // ץѥƥ
+            foreach (get_object_vars($action) as $key => $value) {
+                if (substr($key, 0, 1) != '_') {
+                    if (is_object($value)) {
+                        $this->setParameterRef($key, $value);
+                    } else {
+                        $this->setParameter($key, $value);
+                    }
+                }
+            }
+
             // ץꥱ󥳥ݥͥȺ
             $this->cm->deleteAppComponent();
+            // 󥪥֥Ⱥ
+            unset($action);
+            $this->controller->container->deleteComponent(SYL_ACTION_KEY);
+        } else {
+            // 󥪥֥Ȥ¸ߤʤʥ¹̵ˤʤС
+            // Υ饹ǥեȥץѥƥ
+            $action_file = $this->getActionDir() . $this->getActionFile();
+            if (is_file($action_file)) {
+                include_once $action_file;
+                $action_class = $this->getClassName();
+                if (class_exists($action_class)) {
+                    foreach (get_class_vars($action_class) as $key => $value) {
+                        $this->setParameter($key, $value);
+                    }
+                }
+            }
         }
     }
-
-    /**
-     * 󥪥֥Ȥμ
-     * 
-     * @access public
-     * @return object 󥪥֥
-     */
-    function &getAction()
-    {
-        return $this->action;
-    }
 }
 
 ?>
