@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.6 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.6 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.7 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Cache
@@ -51,6 +51,13 @@ class SyL_Cache
      * @var string
      */
     var $key = '';
+    /**
+     * LbṼL[MD5
+     *
+     * @access private
+     * @var string
+     */
+    var $key_md5 = '';
     /**
      * LbVfBNg
      *
@@ -82,7 +89,8 @@ class SyL_Cache
     function SyL_Cache($key)
     {
         clearstatcache();
-        $this->key = $key;
+        $this->key     = $key;
+        $this->key_md5 = md5($key);
     }
 
     /**
@@ -113,9 +121,20 @@ class SyL_Cache
      */
     function setCacheDir($cache_dir)
     {
-        if (substr($cache_dir, -1) != DIRECTORY_SEPARATOR) {
-            $cache_dir .= DIRECTORY_SEPARATOR;
+        if (!preg_match('/(\\\\|\/)$/', $cache_dir)) {
+            $cache_dir .= '/';
         }
+
+        if (!is_dir($cache_dir)) {
+            if (!mkdir($cache_dir, 0777)) {
+                trigger_error("[SyL error] SyL cache dir can't create ($cache_dir)", E_USER_ERROR);
+            }
+        }
+
+        if (!is_writable($cache_dir)) {
+            trigger_error("[SyL error] SyL cache dir permission denied ($cache_dir)", E_USER_ERROR);
+        }
+
         $this->cache_dir = $cache_dir;
     }
 
@@ -315,15 +334,7 @@ class SyL_Cache
      */
     function getFileName()
     {
-        if ($this->key != '') {
-            if (is_dir($this->cache_dir) && is_writable($this->cache_dir)) {
-                return $this->cache_dir . $this->prefix . md5($this->key);
-            } else {
-                return false;
-            }
-        } else {
-            return false;
-        }
+        return $this->cache_dir . $this->prefix . $this->key_md5;
     }
 
     /**
