@@ -27,11 +27,15 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XMLParser.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XMLParser.php,v 1.8 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+if (!defined('SYL_XML_ENCODE')) {
+    define('SYL_XML_ENCODE', 'UTF-8');
+}
+
 /**
  *  XMLѡ饹
  *
@@ -39,7 +43,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XMLParser.php,v 1.7 2006/12/23 11:13:09 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XMLParser.php,v 1.8 2007/01/03 11:17:37 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_XMLParser
@@ -52,12 +56,12 @@ class SyL_XMLParser
      */
     var $file_name = '';
     /**
-     * ե륵
+     * XMLʸ
      *
      * @access private
      * @var string
      */
-    var $file_size = '';
+    var $xml_encode = SYL_XML_ENCODE;
 
     /**
      * 󥹥ȥ饯
@@ -67,21 +71,21 @@ class SyL_XMLParser
      */
     function SyL_XMLParser($file_name)
     {
-        $this->file_name = $file_name;
-        if (file_exists($this->file_name)) {
-            $this->setStreamSize(filesize($this->file_name));
-        }
+        $this->setFile($file_name);
     }
 
     /**
-     * ȥ꡼򥻥å
+     * XMLե򥻥å
      *
      * @access public
      * @param int ȥ꡼
      */
-    function setStreamSize( $file_size )
+    function setFile($file_name)
     {
-        $this->file_size = $file_size;
+        if (!file_exists($file_name)) {
+            trigger_error("[SyL error] Xml file not found ({$file_name})", E_USER_ERROR);
+        }
+        $this->file_name = $file_name;
     }
 
     /**
@@ -91,51 +95,45 @@ class SyL_XMLParser
      */
     function parseXML()
     {
-        if ($this->file_name == '') {
-            trigger_error( "[SyL error] Xml file not found ({$this->file_name})", E_USER_ERROR );
-        }
-        if ($this->file_size == '') {
-            trigger_error( "[SyL error] Xml file size invalid ({$this->file_name})", E_USER_ERROR );
-        }
-
         // XMLѡ ʸUTF-8
-        $xmlParser = xml_parser_create( 'UTF-8' );
+        $parser = xml_parser_create($this->xml_encode);
         // ʸѴԤʤ
-        xml_parser_set_option( $xmlParser, XML_OPTION_CASE_FOLDING, false );
+        xml_parser_set_option($parser, XML_OPTION_CASE_FOLDING, false);
         // ϥɥ᥽åɤ򥯥饹᥽åɤ
-        xml_set_object( $xmlParser, &$this );
+        xml_set_object($parser, &$this);
         // start  end ǤΥϥɥꤹ
-        xml_set_element_handler( $xmlParser,
-          array( &$this, 'startElement' ),
-          array( &$this, 'endElement'   )
+        xml_set_element_handler( $parser,
+          array(&$this, 'startElement'),
+          array(&$this, 'endElement'  )
         );
         // ʸǡϥɥꤹ
-        xml_set_character_data_handler( $xmlParser, array( &$this, 'characters' ) );
+        xml_set_character_data_handler($parser, array(&$this, 'characters'));
 
         // XMLե륪ץ
-        if (($fp = @fopen( $this->file_name, 'r' )) == false) {
-            trigger_error( "Can't open xml file(" . $this->file_name . ").", E_USER_ERROR );
+        if (($fp = @fopen($this->file_name, 'r')) == false) {
+            trigger_error("[SyL error] Can't open xml file({$this->file_name})", E_USER_ERROR);
         } else {
+            $file_size = filesize($this->file_name);
             // ɤ߹ߤȲ
-            while ($data = fread($fp, $this->file_size)) {
+            while ($data = fread($fp, $file_size)) {
                 // XMLѡ
-                if (!xml_parse( $xmlParser, $data, feof($fp) )){
+                if (!xml_parse($parser, $data, feof($fp))){
                     // ѡ顼
                     trigger_error(
-                      sprintf( "XML parse error: %s at %s(%d).",
-                        xml_error_string(xml_get_error_code($xmlParser)),
+                      sprintf("[SyL error] XML parse error: %s at %s (%d)",
+                        xml_error_string(xml_get_error_code($parser)),
                         $this->file_name,
-                        xml_get_current_line_number($xmlParser)
+                        xml_get_current_line_number($parser)
                       ),
                       E_USER_ERROR
                     );
                 }
             }
             // XMLե륯
-            fclose( $fp );
+            fclose($fp);
         }
         // XMLѡγ 
-        xml_parser_free( $xmlParser );
+        xml_parser_free($parser);
     }
 
     /**
